@@ -1,5 +1,5 @@
 /*
- * Copyright (c) [2016-2019] SUSE LLC
+ * Copyright (c) [2016-2023] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -82,6 +82,8 @@ public:
 
     bool getValue(const string& key, string& value) const;
 
+    bool is_yes(const char* key) const;
+
 private:
 
     map<string, string> values;
@@ -98,6 +100,8 @@ public:
     unsigned int getNum() const { return impl->getNum(); }
     time_t getDate() const { return impl->getDate(); }
     uid_t getUid() const { return impl->getUid(); }
+    bool isReadOnly() const { return impl->isReadOnly(); }
+    void setReadOnly(bool read_only) { impl->setReadOnly(read_only); }
     unsigned int getPreNum() const { return impl->getPreNum(); }
     const string& getDescription() const { return impl->getDescription(); }
     const string& getCleanup() const { return impl->getCleanup(); }
@@ -128,6 +132,8 @@ public:
 	virtual unsigned int getNum() const = 0;
 	virtual time_t getDate() const = 0;
 	virtual uid_t getUid() const = 0;
+	virtual bool isReadOnly() const = 0;
+	virtual void setReadOnly(bool read_only) = 0;
 	virtual unsigned int getPreNum() const = 0;
 	virtual const string& getDescription() const = 0;
 	virtual const string& getCleanup() const = 0;
@@ -175,6 +181,7 @@ public:
     virtual iterator getDefault() = 0;
     virtual const_iterator getDefault() const = 0;
 
+    virtual iterator getActive() = 0;
     virtual const_iterator getActive() const = 0;
 
     iterator find(unsigned int i);
