@@ -15,7 +15,7 @@ main(int argc, char** argv)
     list<Snapper*> sh;
 
     for (list<ConfigInfo>::const_iterator it = c.begin(); it != c.end(); ++it)
-	sh.push_back(new Snapper(it->getConfigName(), "/"));
+	sh.push_back(new Snapper(it->get_config_name(), "/"));
 
     for (list<Snapper*>::const_iterator it = sh.begin(); it != sh.end(); ++it)
 	cout << (*it)->configName() << " " << (*it)->subvolumeDir() << " "
