@@ -1,6 +1,6 @@
 /*
  * Copyright (c) [2012-2015] Novell, Inc.
- * Copyright (c) [2018-2022] SUSE LLC
+ * Copyright (c) [2018-2023] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -62,6 +62,16 @@ MetaSnapper::setConfigInfo(const map<string, string>& raw)
 }
 
 
+void
+MetaSnapper::updateConfigInfo(const char* key)
+{
+    string value;
+
+    if (getSnapper()->getConfigInfo().get_value(key, value))
+	 config_info.set_value(key, value);
+}
+
+
 void
 MetaSnapper::set_permissions()
 {
