@@ -1,5 +1,6 @@
 /*
  * Copyright (c) [2016] Red Hat, Inc.
+ * Copyright (c) 2023 SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -21,7 +22,6 @@
 
 #include <cerrno>
 #include <map>
-
 #include <boost/algorithm/string.hpp>
 
 #include "snapper/AppUtil.h"
@@ -121,7 +121,7 @@ namespace snapper
 	else
 	{
 	    if (errno == ENOENT)
-		y2deb("Selinux context not defined for path " << path);
+		y2deb("SELinux context not defined for path " << path);
 
 	    return NULL;
 	}
@@ -131,13 +131,14 @@ namespace snapper
     bool
     _is_selinux_enabled()
     {
-	static bool selinux_enabled, selinux_checked = false;
+	static bool selinux_enabled = false;
+	static bool selinux_checked = false;
 
 	if (!selinux_checked)
 	{
 	    selinux_enabled = (is_selinux_enabled() == 1); // may return -1 on error
 	    selinux_checked = true;
-	    y2mil("Selinux support " << (selinux_enabled ? "en" : "dis") << "abled");
+	    y2mil("SELinux support " << (selinux_enabled ? "enabled" : "disabled"));
 	}
 
 	return selinux_enabled;
@@ -147,13 +148,9 @@ namespace snapper
     SelinuxLabelHandle*
     SelinuxLabelHandle::get_selinux_handle()
     {
-	if (_is_selinux_enabled())
-	{
-	    static SelinuxLabelHandle handle;
-	    return &handle;
-	}
+	static SelinuxLabelHandle handle;
 
-	return NULL;
+	return &handle;
     }
 
 }
