@@ -22,28 +22,33 @@
 #ifndef SOLVABLE_MATCHER_H
 #define SOLVABLE_MATCHER_H
 
-#include <iostream>
+
 #include <vector>
 #include <string>
 
-struct SolvableMatcher {
-    enum class Kind {
-		     GLOB,
-		     REGEX
-    };
-    std::string pattern;
-    Kind kind;
-    bool important = false;
 
-    static std::ostream& log;
-    SolvableMatcher(const std::string& apattern, Kind akind, bool aimportant)
-	: pattern(apattern)
-	, kind(akind)
-	, important(aimportant)
+class SolvableMatcher
+{
+public:
+
+    enum class Kind { GLOB, REGEX };
+
+    SolvableMatcher(const std::string& pattern, Kind kind, bool important)
+	: pattern(pattern), kind(kind), important(important)
     {}
 
+    bool is_important() const { return important; }
+
     bool match(const std::string& solvable) const;
+
     static std::vector<SolvableMatcher> load_config(const std::string& cfg_filename);
+
+private:
+
+    const std::string pattern;
+    const Kind kind;
+    const bool important;
+
 };
 
-#endif //SOLVABLE_MATCHER_H
+#endif
